==> haskell-interpolate-0.2.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-KKk0PVGxHiz5hugqa8MhiJ
key:                  interpolate-0.2.1-KKk0PVGxHiz5hugqa8MhiJ
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  2b5495d0d9e6c649383e066378e36601
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-8.10.1/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/interpolate-0.2.1
hs-libraries:         HSinterpolate-0.2.1-KKk0PVGxHiz5hugqa8MhiJ
depends:
    base-4.14.0.0 haskell-src-meta-0.8.5-7JgJdZ6MI6ABmir9J9p5XH
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-LjONcB8uBLoG3tydKjnAPt
key:                  interpolate-0.2.1-LjONcB8uBLoG3tydKjnAPt
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  d9c6cb3ace8cc24e43a0e676eac464a5
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-8.10.1/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/interpolate-0.2.1
hs-libraries:         HSinterpolate-0.2.1-LjONcB8uBLoG3tydKjnAPt
depends:
    base-4.14.0.0 haskell-src-meta-0.8.5-HnZMYkMtWQI87gSVAcJYKH
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
